==> 0.11.4.tar.gz: example/lib/views/colorful_header_structure.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/widgets/senior_colorful_header_structure.dart';

class ColorfulHeaderStructureExample extends StatefulWidget {
  const ColorfulHeaderStructureExample({
    Key? key,
  }) : super(key: key);

  @override
  _ColorfulHeaderStructureExampleState createState() =>
      _ColorfulHeaderStructureExampleState();
}

class _ColorfulHeaderStructureExampleState
    extends State<ColorfulHeaderStructureExample> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: DefaultTabController(
        length: 2,
        child: SeniorColorfulHeaderStructure(
          hasTopPadding: true,
          title: Text('Meu Appbar'),
          actions: [
            IconButton(
              onPressed: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (c) => SecondPage(),
                  ),
                );
              },
              icon: Icon(Icons.search),
            ),
          ],
          body: Container(
            color: Colors.white,
            child: Center(
              child: ListView.builder(
                itemCount: 400,
                itemBuilder: (context, index) {
                  return Container(
                    height: 30,
                    child: Center(
                      child: Text(
                        index.toString(),
                      ),
                    ),
                  );
                },
              ),
            ),
          ),
        ),
      ),
    );
  }
}

class SecondPage extends StatefulWidget {
  const SecondPage({Key? key}) : super(key: key);

  @override
  _SecondPageState createState() => _SecondPageState();
}

class _SecondPageState extends State<SecondPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      body: DefaultTabController(
        length: 2,
        child: SeniorColorfulHeaderStructure(
          hasTopPadding: true,
          hasTopShadow: true,
          title: Text('Meu Appbar'),
          body: Container(
            child: Center(
              child: ListView.builder(
                itemCount: 400,
                itemBuilder: (context, index) {
                  return Container(
                    height: 30,
                    child: Center(
                      child: Text(
                        index.toString(),
                      ),
                    ),
                  );
                },
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> 0.15.15.tar.gz: example/lib/views/colorful_header_structure.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/widgets/senior_colorful_header_structure.dart';

class ColorfulHeaderStructureExample extends StatefulWidget {
  const ColorfulHeaderStructureExample({
    Key? key,
  }) : super(key: key);

  @override
  _ColorfulHeaderStructureExampleState createState() =>
      _ColorfulHeaderStructureExampleState();
}

class _ColorfulHeaderStructureExampleState
    extends State<ColorfulHeaderStructureExample> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: DefaultTabController(
        length: 2,
        child: SeniorColorfulHeaderStructure(
          hideLeading: true,
          hasTopPadding: false,
          title: Text('Meu Appbar'),
          actions: [
            IconButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (c) => SecondPage(),
                    ),
                  );
                },
                icon: Icon(Icons.search))
          ],
          body: Container(
            child: Center(
              child: ListView.builder(
                itemCount: 400,
                itemBuilder: (context, index) {
                  return Container(
                    height: 30,
                    child: Center(
                      child: Text(
                        index.toString(),
                      ),
                    ),
                  );
                },
              ),
            ),
          ),
        ),
      ),
    );
  }
}

class SecondPage extends StatefulWidget {
  const SecondPage({Key? key}) : super(key: key);

  @override
  _SecondPageState createState() => _SecondPageState();
}

class _SecondPageState extends State<SecondPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: DefaultTabController(
        length: 2,
        child: SeniorColorfulHeaderStructure(
          onTapBack: () {
            Navigator.pop(context);
          },
          hasTopPadding: false,
          title: Text('Meu Appbar'),
          body: Container(
            child: Center(
              child: ListView.builder(
                itemCount: 400,
                itemBuilder: (context, index) {
                  return Container(
                    height: 30,
                    child: Center(
                      child: Text(
                        index.toString(),
                      ),
                    ),
                  );
                },
              ),
            ),
          ),
        ),
      ),
    );
  }
}
